==> xJdfLib-0.3-sources.jar: org/cip4/lib/xjdf/schema/NumberingParams.java <==

package org.cip4.lib.xjdf.schema;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for NumberingParams complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NumberingParams">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.CIP4.org/JDFSchema_2_0}ParameterType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://www.CIP4.org/JDFSchema_2_0}NumberingParam" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NumberingParams", propOrder = {
    "numberingParams"
})
public class NumberingParams
    extends ParameterType
    implements Serializable
{

    @XmlElement(name = "NumberingParam")
    protected List<NumberingParam> numberingParams;

    /**
     * Gets the value of the numberingParams property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the numberingParams property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNumberingParams().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NumberingParam }
     * 
     * 
     */
    public List<NumberingParam> getNumberingParams() {
        if (numberingParams == null) {
            numberingParams = new ArrayList<NumberingParam>();
        }
        return this.numberingParams;
    }

}

==> xJdfLib-0.4-sources.jar: org/cip4/lib/xjdf/schema/NumberingParams.java <==

package org.cip4.lib.xjdf.schema;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for NumberingParams complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NumberingParams">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.CIP4.org/JDFSchema_2_0}ParameterType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.CIP4.org/JDFSchema_2_0}NumberingParam" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NumberingParams", propOrder = {
    "numberingParam"
})
public class NumberingParams
    extends ParameterType
    implements Serializable
{

    @XmlElement(name = "NumberingParam")
    protected List<NumberingParam> numberingParam;

    /**
     * Gets the value of the numberingParam property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the numberingParam property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNumberingParam().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NumberingParam }
     * 
     * 
     */
    public List<NumberingParam> getNumberingParam() {
        if (numberingParam == null) {
            numberingParam = new ArrayList<NumberingParam>();
        }
        return this.numberingParam;
    }

}
